@@ -2,19 +2,19 @@ package Razor2::Preproc::deHTMLxs;
 
 use strict;
 
-require Exporter;
-require DynaLoader;
-require AutoLoader;
+use Exporter   ();
+use XSLoader   ();
+use AutoLoader ();
 
-our @ISA = qw(Exporter DynaLoader);
+our @ISA = qw(Exporter);
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 our @EXPORT  = qw();
-our $VERSION = '2.85';
+our $VERSION = '2.86';
 
-bootstrap Razor2::Preproc::deHTMLxs $VERSION;
+XSLoader::load( 'Razor2::Preproc::deHTMLxs', $VERSION );
 
 # Preloaded methods go here.
 
